unit Wavemix;

interface

uses
	WinTypes;

{$IFNDEF NOWMIXSTR}
type
	PMixWave = Pointer;
{$ENDIF}

{ flag values for play params }
const
	WMIX_QUEUEWAVE 				= $00;
	WMIX_CLEARQUEUE 			= $01;
	WMIX_USELRUCHANNEL 		= $02;
	WMIX_HIPRIORITY				= $04;
	WMIX_WAIT							= $08;

type
	PMixPlayParams = ^TMixPlayParams;
	TMixPlayParams = record
		wSize : Word;
		hMixSession : THandle;
		iChannel : integer;
		lpMixWave : PMixWave;
		hWndNotify : HWnd;
		dwFlags : LongInt;
		wLoops : Word;  { $FFFF means loop forever }
	end;

	PWaveMixInfo = ^TWaveMixInfo;
	TWaveMixInfo = record
		wSize : Word;
		bVersionMajor : Byte;
		bVersionMinor : Byte;
		szDate : array[0..11] of char; { Mmm dd yyyy }
		dwFormats : LongInt; { see waveOutGetDevCaps (wavemix requires synchronous device) }
	end;

const
	WMIX_CONFIG_CHANNELS 				= $1;
	WMIX_CONFIG_SAMPLINGRATE 		= $2;

type
	PMixConfig = ^TMixConfig;
	TMixConfig = record
		wSize : Word;
		dwFlags : LongInt;
		wChannels : Word;  { 1 = MONO, 2 = STEREO }
		wSamplingRate : Word; { 11,22,44  (11=11025, 22=22050, 44=44100 Hz) }
	end;

	function WaveMixGetInfo(lpWaveMixInfo : PWaveMixInfo) : Word;

{ return same errors as waveOutOpen, waveOutWrite, and waveOutClose }
	function WaveMixInit : THandle; { returns hMixSession - you should keep it and use for subsequent API calls }
	function WaveMixConfigureInit(lpConfig : PMixConfig) : THandle;
	function WaveMixActivate(hMixSession : THandle; fActivate : Boolean) : Word;

const
	WMIX_FILE					= $0001;
	WMIX_RESOURCE			= $0002;
	WMIX_MEMORY				= $0004;

	function WaveMixOpenWave(hMixSession : THandle; szWaveFilename : PChar; hInst : THandle; dwFlags : LongInt) : PMixWave;

const
	WMIX_OPENSINGLE 	= 0;	{ open the single channel specified by iChannel }
	WMIX_OPENALL 			= 1; { opens all the channels, iChannel ignored }
	WMIX_OPENCOUNT 		= 2; { open iChannel Channels (eg. if iChannel = 4 will create channels 0-3) }

	function WaveMixOpenChannel(hMixSession : THandle; iChannel : Integer; dwFlags : LongInt) : Word;

	function WaveMixPlay(lpMixPlayParams : PMixPlayParams) : Word;

const
	WMIX_ALL     		= $0001; { stops sound on all the channels, iChannel ignored }
	WMIX_NOREMIX 		= $0002; { prevents the currently submited blocks from being remixed to exclude new channel }

	function WaveMixFlushChannel(hMixSession : THandle; iChannel : Integer; dwFlags : LongInt) : Word;
	function WaveMixCloseChannel(hMixSession : THandle; iChannel : Integer; dwFlags : LongInt) : Word;

	function WaveMixFreeWave(HMixSession : THandle; lpMixWave : PMixWave) : Word;
	function WaveMixCloseSession(hMixSession : THandle) : Word;
	procedure WaveMixPump;

implementation

	function WaveMixGetInfo;											external 'WAVEMIX' index 14;
	function WaveMixInit;													external 'WAVEMIX' index 3;
	function WaveMixConfigureInit;								external 'WAVEMIX' index 15;
	function WaveMixActivate;											external 'WAVEMIX' index 4;
	function WaveMixOpenWave;											external 'WAVEMIX' index 5;
	function WaveMixOpenChannel;									external 'WAVEMIX' index 6;
	function WaveMixPlay;													external 'WAVEMIX' index 7;
	function WaveMixFlushChannel;									external 'WAVEMIX' index 8;
	function WaveMixCloseChannel;									external 'WAVEMIX' index 9;
	function WaveMixFreeWave;											external 'WAVEMIX' index 10;
	function WaveMixCloseSession;									external 'WAVEMIX' index 11;
	procedure WaveMixPump;												external 'WAVEMIX' index 12;

end.
